---

Name: memcalc

Version: 0.0.1

Description: memcalc is a Python package made for performing essential math calculations for everyday use.

Supported Actions:

- Addition
- Multiplication
- Subtraction
- Division
- nth root calculation
- Memory reset
- Print out memory

---
How to install this package:

1. installing via terminal -

pip install memcalc

2. installing via IDE -

%pip install memcalc

---
How it works:

from calculator.calculator import Calculator

new_obj = calc.Calculator()  # New object is created.

new_obj.add(55) # Returns 55.0

new_obj.subtract(22.6) # Returns 32.4

new_obj.multiply(5) # Returns 162.0

new_obj.divide(2) # Returns 81.0

new_obj.n_root(4) # Returns 3.0

new_obj.return_memory # Returns 3.0

new_obj.memory_reset() # Resets memory to 0.0

---

Keywords: calculator, addition, multiplication, subtraction, division, nth root

This project is licensed under the terms of the MIT license.